﻿'_______________________________________________

'L E G O   N X T B E E   P R O   R E M O T E   C O N T R O L
'                                Ron Kessler
'                                12/4/2011
'_______________________________________________

'Purpose: This controls a Lego NXT via XBEE-PRO radios
'Radios must be connected to port 4 on NXT and that port must use high speed parameter. This is set using
'the DIGI X-CTU program. Be sure to write this info to both your XBEE's.
'Form properties: KeyPreview = True

'Updated 12/8/2011

'12/8/2011  finished debugging

Option Explicit On
Option Strict On

Imports XBEE_NXT_Remote_Control.General
Imports System.IO.Ports

Partial Public Class frmMain



#Region "Constructor"
    Public Sub New()
        InitializeComponent()

        lblStatus.Text = DisconnectedMsg
        btnConnect.Enabled = False
        grpMotors.Enabled = False
    End Sub
#End Region

#Region "Form Load and initialize Combo box for Com ports"
    Private Sub frmMain_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load

        ' Show all available COM ports.
        For Each sp As String In My.Computer.Ports.SerialPortNames
            cboPorts.Items.Add(sp)
        Next
        cboPorts.SelectedIndex = -1     'no selection yet. See text property of cboPorts

    End Sub

    Private Sub cboPorts_SelectedIndexChanged(sender As System.Object, e As System.EventArgs) Handles cboPorts.SelectedIndexChanged

        Try
            whichComPort = cboPorts.SelectedItem.ToString
            If Mid(whichComPort, 1, 3) = "COM" Then
                btnConnect.Enabled = True
            Else
                btnConnect.Enabled = False
            End If

        Catch ex As Exception
            lblStatus.Text = "Cannot access that port."
        End Try
        
    End Sub
#End Region

#Region "Make Com Connection"
    Private Sub btnConnect_Click(sender As System.Object, e As System.EventArgs) Handles btnConnect.Click
        Try

            With RS232
                .PortName = whichComPort.Trim
                .BaudRate = 9600
                .Parity = IO.Ports.Parity.None
                .StopBits = IO.Ports.StopBits.One
                .DataBits = 8
                .Open()
            End With
            lblStatus.Text = ConnectedMsg
            btnConnect.Enabled = False
            grpMotors.Enabled = True
            cboPorts.Focus()         'keeps buttons from handling my arrow keydown events
        Catch ex As Exception
            MessageBox.Show("Unable to connect." & ex.Message, "System Message", MessageBoxButtons.OK, MessageBoxIcon.Error)
            lblStatus.Text = DisconnectedMsg
            btnConnect.Enabled = True
            grpMotors.Enabled = False
        End Try
    End Sub
#End Region

#Region "Idle and Disconnect"
    Private Sub btnDisconnect_Click(sender As System.Object, e As System.EventArgs) Handles btnDisconnect.Click
        Disconnect()
    End Sub

    Private Sub Disconnect()
        '---clean up
        lblStatus.Text = DisconnectedMsg
        grpMotors.Enabled = False
        RS232.Close()
    End Sub

    Private Sub btnExit_Click(sender As System.Object, e As System.EventArgs) Handles btnExit.Click
        Disconnect()
        Me.Close()

    End Sub

    Private Sub frmMain_FormClosing(sender As Object, e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        Disconnect()
    End Sub
#End Region

  
End Class
